@@ -1,6 +1,27 @@
 <?php
 /**
- * @licence http://opensource.org/licenses/gpl-2.0.php GPL
+ * TODO short desc
+ *
+ * TODO long desc
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+ * USA.
+ * 
+ * @author      Olivier Bilodeau <obilodeau@inverse.ca>
+ * @copyright   2008-2010 Inverse inc.
+ * @license     http://opensource.org/licenses/gpl-2.0.php      GPL
  */
 
   $current_top = 'node';
@@ -55,13 +76,37 @@
     }
 
     $pretty_key = pretty_header("$current_top-view", $key);
-    if($key == 'status'){
+    switch($key) {
+    case 'status':
       print "<tr><td></td><td>$pretty_key:</td><td>";
-      printSelect( array('unreg' => 'Unregistered', 'reg' => 'Registered', 'grace' => 'Grace'), 'hash', $val, "name='$key'");
-    } elseif ($key == 'category'){
+      printSelect(get_node_status_for_dropdown(), 'hash', $val, "name='$key'");
+      break;
+
+    case 'category':
       print "<tr><td></td><td>$pretty_key:</td><td>";
       printSelect(get_nodecategories_for_dropdown(), 'hash', $val, "name='$key'");
-    } else{
+      break;
+
+    case 'voip':
+      print "<tr><td></td><td>$pretty_key:</td><td>";
+      printSelect( array('no' => 'No', 'yes' => 'Yes'), 'hash', $val, "name='$key'");
+      break;
+
+    case 'dhcp_fingerprint':
+    case 'user_agent':
+    case 'last_switch':
+    case 'last_port':
+    case 'last_vlan':
+    case 'last_ssid':
+    case 'last_dot1x_username':
+      print "<tr><td></td><td>$pretty_key:</td><td><input type='text' name='$key' value='$val' disabled>";
+      break;
+
+    case 'last_connection_type':
+      print "<tr><td></td><td>$pretty_key:</td><td><p title='$val' style='font-size: 0.7em;'>$connection_type[$val]</p>";
+      break;
+
+    default:
       print "<tr><td></td><td>$pretty_key:</td><td><input type='text' name='$key' value='$val'>";
     }
 
