@@ -45,6 +45,10 @@ Warning: The list of subroutine is incomplete
 =over
 
 =cut
+
+# capabilities
+sub supportsFloatingDevice { return $TRUE; }
+
 sub getMinOSVersion {
     my $this   = shift;
     my $logger = Log::Log4perl::get_logger( ref($this) );
@@ -70,7 +74,7 @@ sub getManagedPorts {
     if ( defined($ifTypes) ) {
 
         foreach my $port ( keys %{$ifTypes} ) {
-            if ( $ifTypes->{$port} == 6 )
+            if ( $ifTypes->{$port} == $SNMP::ETHERNET_CSMACD )
             {           # skip non ethernetCsmacd port type
 
                 $port =~ /^$oid_ifType\.(\d+)$/;
@@ -440,16 +444,6 @@ sub ping {
     return 1;
 }
 
-=item supportsFloatingDevice - Does this switch type supports floating network devices ?
-
-Only Catalyst 2900XL and 3500XL does not so far...
-
-=cut
-sub supportsFloatingDevice {
-    my ( $this ) = @_;
-
-    return 1;
-}
 
 =item enablePortSecurityByIfIndex - configure the port with port-security settings
 
@@ -775,6 +769,7 @@ sub removeAllTaggedVlan {
     my $taggedVlanMembers = pack("B*", $bitString);
     my $taggedVlanMembers4k = pack("B*", $bitString4k);
 
+    $logger->trace("SNMP set_request for OID_vlanTrunkPortVlansEnabled: $OID_vlanTrunkPortVlansEnabled");
     my $result = $this->{_sessionWrite}->set_request( -varbindlist => [
         "$OID_vlanTrunkPortVlansEnabled.$ifIndex", Net::SNMP::OCTET_STRING, $taggedVlanMembers,
         "$OID_vlanTrunkPortVlansEnabled2k.$ifIndex", Net::SNMP::OCTET_STRING, pack("B*", 1 x 1024),
