@@ -41,6 +41,7 @@ our (
     $dhcp_fingerprints_file, $dhcp_fingerprints_url,
     $oui_file, $oui_url,
     $floating_devices_file, %ConfigFloatingDevices,
+    %connection_type, %connection_type_to_str, %connection_type_explained,
     $blackholemac, $portscan_sid, @valid_trigger_types, $thread, $default_pid, $fqdn
 );
 
@@ -62,11 +63,16 @@ BEGIN {
         $floating_devices_file %ConfigFloatingDevices
         $blackholemac $portscan_sid @valid_trigger_types $thread $default_pid $fqdn
         $FALSE $TRUE
+        WIRELESS_802_1X WIRELESS_MAC_AUTH WIRED_802_1X WIRED_MAC_AUTH WIRED_SNMP_TRAPS WIRELESS WIRED EAP
+        VOIP NO_VOIP
+        LOOPBACK_IPV4
+        %connection_type %connection_type_to_str %connection_type_explained
     );
 }
 
 $thread = 0;
 
+# TODO bug#920 all application config data should use Readonly to avoid accidental post-startup alterration
 $install_dir = '/usr/local/pf';
 $bin_dir     = File::Spec->catdir( $install_dir, "bin" );
 $conf_dir    = File::Spec->catdir( $install_dir, "conf" );
@@ -98,6 +104,53 @@ $dhcp_fingerprints_url = 'http://www.packetfence.org/dhcp_fingerprints.conf';
 $portscan_sid = 1200003;
 $default_pid  = 1;
 
+# connection type constants
+use constant WIRELESS_802_1X => 0b11000001;
+use constant WIRELESS_MAC_AUTH => 0b10000010;
+use constant WIRED_802_1X => 0b01100100;
+use constant WIRED_MAC_AUTH => 0b00101000;
+use constant WIRED_SNMP_TRAPS => 0b00110000;
+# masks to be used on connection types
+use constant WIRELESS => 0b10000000;
+use constant WIRED => 0b00100000;
+use constant EAP => 0b01000000;
+
+# TODO we should build a connection data class with these hashes and related constants
+# String to constant hash
+%connection_type = (
+    'Wireless-802.11-EAP'   => WIRELESS_802_1X,
+    'Wireless-802.11-NoEAP' => WIRELESS_MAC_AUTH,
+    'Ethernet-EAP'          => WIRED_802_1X,
+    'Ethernet-NoEAP'        => WIRED_MAC_AUTH,
+    'SNMP-Traps'            => WIRED_SNMP_TRAPS,
+);
+
+# Note that the () in the hashes below is a trick to prevent bareword quoting so I can store 
+# my constant values as keys of the hashes. See CAVEATS section of perldoc constant.
+# Their string equivalent for database storage
+%connection_type_to_str = (
+    WIRELESS_802_1X() => 'Wireless-802.11-EAP',
+    WIRELESS_MAC_AUTH() => 'Wireless-802.11-NoEAP',
+    WIRED_802_1X() => 'Ethernet-EAP',
+    WIRED_MAC_AUTH() => 'Ethernet-NoEAP',
+    WIRED_SNMP_TRAPS() => 'SNMP-Traps',
+);
+
+# String to constant hash
+# these duplicated in html/admin/common.php for web admin display
+# changes here should be reflected there
+%connection_type_explained = (
+    WIRELESS_802_1X() => 'WiFi 802.1X',
+    WIRELESS_MAC_AUTH() => 'WiFi MAC Auth',
+    WIRED_802_1X() => 'Wired 802.1x',
+    WIRED_MAC_AUTH() => 'Wired MAC Auth',
+    WIRED_SNMP_TRAPS() => 'Wired SNMP',
+);
+
+# VoIP constants
+use constant VOIP    => 'yes';
+use constant NO_VOIP => 'no';
+
 # to shut up strict warnings
 $ENV{PATH} = '/sbin:/bin:/usr/bin:/usr/sbin';
 
@@ -108,6 +161,7 @@ $black_mark = "2";
 
 # this is broken NIC on Dave's desk - it better be unique!
 $blackholemac = "00:60:8c:83:d7:34";
+use constant LOOPBACK_IPV4 => '127.0.0.1';
 
 readPfConfigFiles();
 
@@ -277,8 +331,12 @@ sub readFloatingNetworkDeviceFile {
     #remove trailing spaces..
     foreach my $section ( tied(%ConfigFloatingDevices)->Sections ) {   
         foreach my $key ( keys %{ $ConfigFloatingDevices{$section} } ) {
-            if (($key eq 'trunkPort') && ($ConfigFloatingDevices{$section}{$key} =~ /^\s*(y|yes|true|enabled|1)\s*$/i)){
-                $ConfigFloatingDevices{$section}{$key} = '1';
+            if ($key eq 'trunkPort') {
+                if ($ConfigFloatingDevices{$section}{$key} =~ /^\s*(y|yes|true|enabled|1)\s*$/i) {
+                    $ConfigFloatingDevices{$section}{$key} = '1';
+                } else {
+                    $ConfigFloatingDevices{$section}{$key} = '0';
+                }
             } else {
                 $ConfigFloatingDevices{$section}{$key} =~ s/\s+$//;
             }
